"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.useControllableState = exports.useControllableProp = void 0;
const react_1 = __importDefault(require("react"));
function useControllableProp(prop, state) {
    const { current: isControlled } = react_1.default.useRef(prop !== undefined);
    const value = isControlled && typeof prop !== 'undefined' ? prop : state;
    return [isControlled, value];
}
exports.useControllableProp = useControllableProp;
/**
 * React hook for using controlling component state.
 * @param props
 */
function useControllableState(props) {
    const { value: valueProp, defaultValue, onChange } = props;
    const [valueState, setValue] = react_1.default.useState(defaultValue);
    const isControlled = valueProp !== undefined;
    const value = isControlled ? valueProp : valueState;
    const updateValue = react_1.default.useCallback((next) => {
        const nextValue = typeof next === 'function' ? next(value) : next;
        if (!isControlled) {
            setValue(nextValue);
        }
        onChange && onChange(nextValue);
    }, [isControlled, onChange, value]);
    return [value, updateValue];
}
exports.useControllableState = useControllableState;
